==> bones_api-1.0.25.tar.gz: ___project_name_dir___/README.md <==
# ___project_name___

___project_description___

## Serving the API

To ser the API in this project:

- Go to the project directory:
  ```shell
  cd /path/to/___project_name_dir___
  ```

- Get the project dependencies:
  ```shell
  dart pub get
  ```

- Serve the API through `APIServer` (HTTP Server):
  ```shell
  bones_api serve -d . -c MyAPIRoot -b -i api-local.yaml
  ```
  - "-d": The directory of the project.
  - "-c": The `APIRoot` class name to serve.
  - "-b": Allows automatic reflection build if the inspector detects the need at startup.
  - "-i": API Configuration file.

The `bones_api serve` output should finish with something be similar to:

```text
...

** APIServer Started.

APIServer{ apiType: MyAPIRoot, apiRoot: ___project_name_dir___[1.0.0]{info, account}, address: localhost, port: 8080, hotReload: false, started: true, stopped: false }

URL: http://localhost:8080/
```

## PostgreSQL Docker Container

This project needs a database and the `APIEntityRepositoryProvider` class
is using a `PostgreSQL` adapter.

To run a local `PostgreSQL` with Docker you can run the command:

```shell
docker run --name myapi-postgres -p 5432:5432 -e POSTGRES_PASSWORD=123456 -e POSTGRES_USER=postgres -e POSTGRES_DB=postgres -d postgres
```

The parameters above should be compatible with the configuration file `api-local.yaml`.


To connect to the DB using the psql client:

```shell
docker exec -it myapi-postgres /usr/bin/psql -U postgres
```

This will show the `psql` console.

To list the current tables you can use the command `\d`:

```
postgres=# \d
Did not find any relations.
```

- Nothe that a fresh database won't have any table.

Then you can create the tables used in this project:

```

CREATE TABLE IF NOT EXISTS "address" (
	"id" serial,
	"countrycode" text,
	"state" text,
	"city" text,
	"address1" text,
	"address2" text,
	"zipcode" text,
	PRIMARY KEY( id )
);

CREATE TABLE IF NOT EXISTS "account" (
	"id" serial,
	"email" text,
	"passwordHash" text,
	"address" integer CONSTRAINT address_ref_account_fk REFERENCES address(id),
	"creation_time" timestamp,
	PRIMARY KEY( id )
);

```

To list the current tables:

```
postgres=# \d
               List of relations
 Schema |      Name      |   Type   |  Owner   
--------+----------------+----------+----------
 public | account        | table    | postgres
 public | account_id_seq | sequence | postgres
 public | address        | table    | postgres
 public | address_id_seq | sequence | postgres
(4 rows)
```

Now you have a running databse that your API can connect and use.


## Calling the API (HTTP)


To add an `Account`:

- http://localhost:8080/account/add?email=joe@mail.com&password=123&countryCode=US&state=SC&city=NY

To select `Account`s by `Address.state`:

- http://localhost:8080/account/byState?state=NY


*See the class `ModuleAccount` for more routes.*


## Bones_API

See the package `bones_api` for more information:

- https://pub.dev/packages/bones_api

==> bones_api-1.1.32.tar.gz: ___project_name_dir___/README.md <==
# ___project_name___

___project_description___

## Serving the API

To ser the API in this project:

- Go to the project directory:
  ```shell
  cd /path/to/___project_name_dir___
  ```

- Get the project dependencies:
  ```shell
  dart pub get
  ```

- Serve the API through `APIServer` (HTTP Server):
  ```shell
  bones_api serve -d . -c MyAPIRoot -b -i api-local.yaml
  ```
  - "-d": The directory of the project.
  - "-c": The `APIRoot` class name to serve.
  - "-b": Allows automatic reflection build if the inspector detects the need at startup.
  - "-i": API Configuration file.

The `bones_api serve` output should finish with something be similar to:

```text
...

** APIServer Started.

APIServer{ apiType: MyAPIRoot, apiRoot: ___project_name_dir___[1.0.0]{info, account}, address: localhost, port: 8080, hotReload: false, started: true, stopped: false }

URL: http://localhost:8080/
```

## PostgreSQL Docker Container

This project needs a database and the `APIEntityRepositoryProvider` class
is using a `PostgreSQL` adapter.

To run a local `PostgreSQL` with Docker you can run the command:

```shell
docker run --name myapi-postgres -p 5432:5432 -e POSTGRES_PASSWORD=123456 -e POSTGRES_USER=postgres -e POSTGRES_DB=postgres -d postgres
```

The parameters above should be compatible with the configuration file `api-local.yaml`.


To connect to the DB using the psql client:

```shell
docker exec -it myapi-postgres /usr/bin/psql -U postgres
```

This will show the `psql` console.

To list the current tables you can use the command `\d`:

```
postgres=# \d
Did not find any relations.
```

- Nothe that a fresh database won't have any table.

Then you can create the tables used in this project:

```

CREATE TABLE IF NOT EXISTS "address" (
	"id" serial,
	"countrycode" text,
	"state" text,
	"city" text,
	"address1" text,
	"address2" text,
	"zipcode" text,
	PRIMARY KEY( id )
);

CREATE TABLE IF NOT EXISTS "account" (
	"id" serial,
	"email" text,
	"passwordHash" text,
	"address" integer CONSTRAINT address_ref_account_fk REFERENCES address(id),
	"creation_time" timestamp,
	PRIMARY KEY( id )
);

```

To list the current tables:

```
postgres=# \d
               List of relations
 Schema |      Name      |   Type   |  Owner   
--------+----------------+----------+----------
 public | account        | table    | postgres
 public | account_id_seq | sequence | postgres
 public | address        | table    | postgres
 public | address_id_seq | sequence | postgres
(4 rows)
```

Now you have a running databse that your API can connect and use.


## Calling the API (HTTP)

To add an `Account`:

- http://localhost:8080/account/add?email=joe@mail.com&password=123&countryCode=US&state=NY&city=Buffalo

To select `Account`s by `Address.state`:

- http://localhost:8080/account/byState?state=NY

*See the class `ModuleAccount` for more routes.*


## Bones_API

See the package `bones_api` for more information:

- https://pub.dev/packages/bones_api
